@@ -28,7 +28,7 @@ if (( $(crontab -l | grep -c "cron_{{ jobName }}" ) == 0 )) ; then
     if (( $(crontab -l | grep -c "APP_NAME=" ) == 0 )) ; then
         env >> _cron
     fi
-    echo "{{ time }} $PWD/cron/{{ jobName }} >> $HOME/app/log/cron_{{ jobName }}.log" >> _cron
+    echo "{{ time }} $PWD/cron/Crontask.sh -i {{ hchk }} -l $HOME/app/log/ null null cmd "\""$PWD/cron/{{ jobName }} >> $HOME/app/log/cron_{{ jobName }}.log"\""" >> _cron
     crontab _cron
     rm -f _cron
 fi
\ No newline at end of file
